# Ramsey One-Vertex Extension and Checking (ROVEaC)

This is the repo for Ramsey theory utilities assisting in one-vertex extension and 
counterexample checking.

## Links
- [Documentation](https://ramsey-ove-and-check.readthedocs.io/en/latest/)
- [Repository](https://github.com/aLehav/ramsey-ove-and-check/)
- [Package](https://pypi.org/project/roveac/)
- [Preprint](https://arxiv.org/abs/2411.04267)
## Notes
Repository and documentation solely maintained by Adam M. Lehavi